@@ -2,21 +2,49 @@
 Form definitions
 """
 
+import re
+
 from django import forms
 from django.forms import ModelForm
+from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
 
 from aasrp.models import AaSrpLink, AaSrpRequest, AaSrpUserSettings
 
 
+def get_mandatory_form_label_text(text: str) -> str:
+    """
+    label text for mandatory form fields
+    :param text:
+    :type text:
+    :return:
+    :rtype:
+    """
+
+    required_text = _("This field is mandatory")
+    required_marker = (
+        f'<span aria-label="{required_text}" class="form-required-marker">*</span>'
+    )
+
+    return mark_safe(
+        f'<span class="form-field-required">{text} {required_marker}</span>'
+    )
+
+
 class AaSrpLinkForm(ModelForm):
     """
     new SRP lnk form
     """
 
-    srp_name = forms.CharField(required=True, label=_("Fleet Name"))
-    fleet_time = forms.DateTimeField(required=True, label=_("Fleet Time"))
-    fleet_doctrine = forms.CharField(required=True, label=_("Fleet Doctrine"))
+    srp_name = forms.CharField(
+        required=True, label=get_mandatory_form_label_text(_("Fleet Name"))
+    )
+    fleet_time = forms.DateTimeField(
+        required=True, label=get_mandatory_form_label_text(_("Fleet Time"))
+    )
+    fleet_doctrine = forms.CharField(
+        required=True, label=get_mandatory_form_label_text(_("Fleet Doctrine"))
+    )
     aar_link = forms.CharField(required=False, label=_("AAR Link"))
 
     class Meta:  # pylint: disable=too-few-public-methods
@@ -50,20 +78,24 @@ class AaSrpRequestForm(ModelForm):
     srp request form
     """
 
-    killboard_link = forms.CharField(
-        label=_("zKillboard Link"),
+    killboard_link = forms.URLField(
+        label=get_mandatory_form_label_text(_("zKillboard Link")),
         max_length=254,
         required=True,
-        help_text="Find your kill mail on https://zkillboard.com and paste the lnk here.",
+        help_text=(
+            "Find your kill mail on https://zkillboard.com " "and paste the link here."
+        ),
     )
 
     additional_info = forms.CharField(
         widget=forms.Textarea(attrs={"rows": 10, "cols": 20, "input_type": "textarea"}),
         required=True,
-        label=_("Additional Info"),
-        help_text="Please tell us about the circumstances of your untimely demise. "
-        "Who was the FC, what doctrine was called, have changes to the fit "
-        "been requested and so on. Be as detailed as you can.",
+        label=get_mandatory_form_label_text(_("Additional Info")),
+        help_text=(
+            "Please tell us about the circumstances of your untimely demise. "
+            "Who was the FC, what doctrine was called, have changes to the fit "
+            "been requested and so on. Be as detailed as you can."
+        ),
     )
 
     class Meta:  # pylint: disable=too-few-public-methods
@@ -82,14 +114,16 @@ class AaSrpRequestForm(ModelForm):
 
         killboard_link = self.cleaned_data["killboard_link"]
 
+        # check if it's a zkillboard link
         if "zkillboard.com" not in killboard_link:
             raise forms.ValidationError(
                 _("Invalid Link. Please use https://zkillboard.com")
             )
 
-        if "https://zkillboard.com/kill/" not in killboard_link:
+        # check if it's an actual kill mail
+        if not re.match(r"http[s]?://zkillboard\.com/kill/\d+\/", killboard_link):
             raise forms.ValidationError(
-                _("Invalid Link. Please post a link that is actually a killmail.")
+                _("Invalid Link. Please post a link to a kill mail.")
             )
 
         # check if there is already a SRP request for this killmail
@@ -120,7 +154,7 @@ class AaSrpRequestRejectForm(forms.Form):
     reject_info = forms.CharField(
         widget=forms.Textarea(attrs={"rows": 10, "cols": 20, "input_type": "textarea"}),
         required=True,
-        label=_("Rejection Reason"),
+        label=get_mandatory_form_label_text(_("Rejection Reason")),
         help_text=_("Please provide the reason why this SRP request is rejected."),
     )
 
